@@ -181,7 +181,25 @@ fn info_dialogt() {
 
 // settings! macro test
 #[test]
-fn settings() {
+fn settings1() {
+    let runlock = RUN.lock().unwrap();
+    let mut root = cursive::default();
+    root.set_theme(better_theme());
+    root.add_fullscreen_layer(
+        settings_cb!(
+            "Coof Testing",
+            "Test",
+            |view| view.quit(),
+            TextView::new("Variant:"),
+            EditView::new().content("delta")
+        )
+    );
+    root.run();
+    drop(runlock);
+}
+
+#[test]
+fn settings2() {
     let runlock = RUN.lock().unwrap();
     let mut root = cursive::default();
     root.set_theme(better_theme());
@@ -189,8 +207,8 @@ fn settings() {
         settings!(
             "Coof Testing",
             |view| view.quit(),
-            TextView::new("Option:"),
-            EditView::new()
+            TextView::new("Variant:"),
+            EditView::new().content("delta")
         )
     );
     root.run();
